@@ -7,8 +7,9 @@ class Verdict:
         return self.short_name + ': ' + self.name
 
 Correct = Verdict('AC', 'All Correct', 0)
-WrongAnswer = Verdict('WA', 'Wrong Answer', 1)
-PresentationError = Verdict('PE', 'PresentationError', 2)
+# 1 and 2 reserved
+WrongAnswer = Verdict('WA', 'Wrong Answer', 3)
+PresentationError = Verdict('PE', 'Presentation Error', 4)
 
 class Response:
     def __init__(self, verdict, message=''):
@@ -19,3 +20,8 @@ class Response:
         if self.message != '':
             ret = ret + '\n' + self.message
         return ret
+    def to_JSON(self):
+        return {
+            self.verdict,
+            self.message
+        }
